.\" man: PHP-Markdown-Extended Manual
.\" man-name: markdown-extended
.\" author: Pierre Cassat
.\" date: 2015-04-16
.\" version: 0.1.0-dev
.TH  "markdown-extended" "3" "2015-04-16" "Version 0.1.0-dev" "PHP-Markdown-Extended Manual"
.SH NAME
.PP
PHP-Markdown-Extended - Yet another PHP parser for the markdown (\fIextended\fP) syntax.
.SH SYNOPSIS
.PP
\fBmarkdown-extended\fP  [\fIoptions\fP]  (\fI--\fP)  [\fIarguments\fP]
.PP
\fBmarkdown-extended\fP  [\fB-V\fP|\fB--version\fP]  [\fB-h\fP|\fB--help\fP]
    [\fB-x\fP|\fB-v\fP|\fB-q\fP] [\fB--debug\fP|\fB--verbose\fP|\fB--quiet\fP|\fB--force\fP]
    [\fB-o\fP|\fB--output\fP \fIfilename\fP] [\fB--no-output\fP]
    [\fB-c\fP|\fB--config\fP \fIfilename\fP]
    [\fB-f\fP|\fB--format\fP \fIformat\fP]
    [\fB-r\fP|\fB--response\fP \fItype\fP]
    [\fB-e\fP|\fB--extract\fP [=\fIblock\fP]]
    [\fB-t\fP|\fB--template\fP [=\fIfilename\fP]] [\fB--no-template\fP]
        \fIinput_filename\fP  [\fIinput_filename\fP]  [...]
        "\fImarkdown string read from STDIN\fP"
.SH DESCRIPTION
.PP
\fBPHP-Markdown-Extended\fP converts markdown-extended syntax text(s) source(s) from specified file(s)
(or STDIN). The rendering can be the full parsed content or just a part of this content.
By default, result is written through STDOUT in HTML format.
.PP
To transform a file content, write its path as script argument. To process a list of input
files, just write the concerned paths as arguments, separated by a space.
.PP
To transform a string read from STDIN, write it as last argument between quotes or EOF.
To process a list of input strings, just write them as arguments, separated by a space.
You can also use the output of a previous command with the pipe notation.
.PP
For more information about the \fBmarkdown extended syntax\fP, see <http://aboutmde.org/>.
.PP
Developers (or curious people) can refer to <markdown-extended(7)> for an internal
\fBPHP-Markdown-Extended\fP documentation.
.SH OPTIONS
.SS Usage of script's options
.PP
You can group short options like `\fS-xc\fP`, set an option argument like `\fS-d(=)value\fP` or
`\fS--long=value\fP` or `\fS--long value\fP` and use the double-dash notation `\fS--\fP` to explicitly 
specify the end of the script options. You can mix short and long options at your 
convenience.
.PP
The equal sign separator for an option with argument IS REQUIRED when this argument
is optional (see the list below). It is NOT required when the option requires an
argument.
.PP
Options are treated in the command line order (`\fS-vq\fP` will finally retain `\fS-q\fP`).
.SS The following options are supported by the CLI interface:
.TP
\fB-h\fP , \fB--help\fP
Get a simple help information.
.TP
\fB-V\fP , \fB--version\fP
Get the current package version number and information ; use option \fBquiet\fP to
get only the version number.
.TP
\fB-r\fP , \fB--response\fP \fItype\fP
Specify the CLI response type to get in \fIplain\fP (default), \fIjson\fP or \fIphp\fP ; using
another type than "plain" will render the full content object (not just the parsed content) ;
using the "php" response type will render a serialization of concerned contents.
.TP
\fB-e\fP , \fB--extract\fP [=\fImeta\fP]
Define a content block to extract ; default extracted block is \fImetadata\fP ; you can
extract any "block" of the content object ; use a metadata name to extract its value.
.TP
\fB-q\fP , \fB--quiet\fP
Decrease script's verbosity ; only result strings, Markdown parser and PHP error
messages are written on \fISTDOUT\fP or \fISTDERR\fP ; this mode disables \fBverbose\fP one.
.TP
\fB-v\fP , \fB--verbose\fP
Increase script's verbosity ; some steps are explained on \fISTDOUT\fP ; this mode
disables \fBquiet\fP one.
.PP
A special \fB--debug\fP or \fB-x\fP option can be used during development to drastically
increase script's verbosity.
.SS The following options are loaded in the markdown parser:
.TP
\fB-c\fP , \fB--config\fP \fIfilename\fP
Define a specific configuration filename to use for the Markdown parser ;
configuration files must be in \fIINI\fP or \fIJSON\fP format.
.TP
\fB-f\fP , \fB--format\fP \fItype\fP
Define the output format to use to generate final rendering ; internal formats 
are "html" and "man" (for manpage) ; you can specify your own output format class ; 
default is \fIhtml\fP.
.TP
\fB-o\fP , \fB--output\fP \fIfilename\fP
Specify a single file name or a file names mask to write generated content(s) in ; by
default, files are generated in current working directory ; masks may use the \fI%%\fP string
which will be fill in with content's identifier.
.TP
\fB--no-output\fP
Prohibits to write the result in a file.
.TP
\fB-t\fP , \fB--template\fP [=\fIfilename\fP]
Return the content inserted in a parsed template file ; if no \fBfilename\fP argument is 
passed, this will use the configuration template file.
.TP
\fB--no-template\fP
Prohibits use of a template.
.TP
\fB--force\fP
Use this to not backup generated files (the default behavior is to backup all existing files
to a "FILENAME.EXT~YYYY-MM-DD-HH-II-SS" file).
.SH RESULT
.PP
The command result can have various types. Actually, for all the types described below, the
\fI--response\fP option will define the final response content type.
.PP
With no \fI--extract\fP neither \fI--output\fP option defined, the command will render a `\fSContent\fP` 
object with transformed content. In fact, if you use the default "plain" response type, the
result will write the rendering content (a raw string) on the terminal. If you specify the
"json" or "php" response type, the full object will be dumped, with the following items:
.RS
.IP \(bu 
\fIcontent\fP: the final rendered content ; this can be the "body" only for a simple one-line
markdown content, the "metadata + body + notes" as a string for a more complex markdown content
and the rendering of the parsed template if a \fI--template\fP option was used ;
.IP \(bu 
\fIbody\fP: the actual "body" of the parsed content, without metadata and notes ;
.IP \(bu 
\fInotes\fP: the footnotes of the content (if so) as an array ;
.IP \(bu 
\fImetadata\fP: the metadata of the content (if so) as an array ;
.IP \(bu 
\fIcharset\fP: the defined character set of the content ;
.IP \(bu 
\fItitle\fP: the guessed title of the content.
.RE
.PP
If you use a \fI--output\fP option, the content described above will be written in a file and the result
rendered on terminal will be the name of this file.
.PP
When you use the \fIPHP\fP response output, you will mostly have a serialized object as output.
To rebuild the original object, you will need to include its definition:
.RS

.EX
markdown-extended -r=php demo/MD_syntax.md > test-php.txt
.br
php -r 'require "src/bootstrap.php"; $obj = file_get_contents("test-php.txt"); var_export(unserialize($obj));'
.EE
.RE
.SS Templating
.PP
The templating system of PHP-Markdown-Extended is a simple processor that will replace
a tag like `\fS{% BODY %}\fP` by its value for concerned content. Such notation can be used for
all content's items listed above: \fIbody\fP, \fItitle\fP, \fIcharset\fP, \fImeta\fP (\fImetadata\fP as string) and
\fInotes\fP (as string).
.PP
The metadata follows a specific rule as you can access each data value by its name with a
tag like `\fS{% META:data_name %}\fP`.
.SH MESSAGES
.PP
The script output is designed to use options \fB-v\fP or \fB--verbose\fP to increase
script verbosity and \fB-q\fP or \fB--quiet\fP to decrease it. The idea is quiet simple:
.RS
.IP \(bu 
in "\fBnormal\fP" rendering (no "verbose" neither than "quiet" mode), the result of the 
processed content is rendered, with the file name header in case of multi-files input
and command line script's errors are rendered ;
.IP \(bu 
in "\fBverbose\fP" mode, some process information are shown, informing user about what is
happening, helps to follow process execution and get some information such as some
string lengths ; the command line script errors are rendered ;
.IP \(bu 
in "\fBquiet\fP" mode, nothing is written through SDTOUT except result of parsed content(s) ;
the command line script's errors are NOT rendered.
.RE
.PP
For all of these cases, PHP errors caught during Markdown Extended classes execution are
rendered depending on your environment \fIerror_reporting\fP setting and script execution may
exit with an error status code between \fI90\fP and \fI95\fP.
.SH ENVIRONMENT
.PP
This script requires PHP version 5.3.3 <http://php.net/> minimum with the
PCRE extension <http://php.net/manual/en/book.pcre.php> (this is the case
by default).
.SH EXAMPLES
.PP
Classic parsing of the content of the Markdown syntax file `\fSsample.md\fP`:
.RS

.EX
path/to/markdown-extended sample.md
.EE
.RE
.PP
For the same example, writing the output in file `\fSsample_parsed.html\fP`, run:
.RS

.EX
path/to/markdown-extended -o sample_parsed.html sample.md
.EE
.RE
.PP
To extract meta-data from `\fSsample.md\fP`, run:
.RS

.EX
path/to/markdown-extended -e sample.md
.EE
.RE
.PP
To build a man-page formatted file from the Markdown source `\fSman-sample.md\fP`, run:
.RS

.EX
path/to/markdown-extended -f man -o man-sample.man man-sample.md
.br
// to open it with `man`:
.br
man ./man-sample.man
.EE
.RE
.PP
To transform a string read from STDIN, run:
.RS

.EX
path/to/markdown-extended -e=body "My **Markdown** string"
.EE
.RE
.PP
To transform a string read from another command output, run:
.RS

.EX
echo "My **Markdown** string" | path/to/markdown-extended -e=body
.EE
.RE
.SH LICENSE
.PP
This software is released under the BSD-3-Clause license. Please
read the LICENSE file for more information, or see
<http://opensource.org/licenses/BSD-3-Clause>.
.PP
PHP Markdown Extended - 
Copyright (c) 2008-2015 Pierre Cassat - 
<http://e-piwi.fr/>
.PP
Based on MultiMarkdown - 
Copyright (c) 2005-2009 Fletcher T. Penney - 
<http://fletcherpenney.net/>
.PP
Based on PHP Markdown Lib - 
Copyright (c) 2004-2012 Michel Fortin - 
<http://michelf.com/>
.PP
Based on Markdown - 
Copyright (c) 2004-2006 John Gruber - 
<http://daringfireball.net/>
.SH BUGS
.PP
To transmit bugs, see <http://github.com/piwi/markdown-extended/issues>.
.SH AUTHOR
.PP
Created and maintained by Pierre Cassat (piwi - <http://e-piwi.fr/>) & contributors.
.SH SEE ALSO
.PP
php(1), pcre(3), markdown-extended(7)
