.\" man: PHP-Markdown-Extended Developer Manual
.\" man-name: markdown-extended-api
.\" section: 7
.\" author: Pierre Cassat
.\" date: 2015-04-16
.\" version: 0.1.0-dev
.TH  "markdown-extended-api" "7" "2015-04-16" "Version 0.1.0-dev" "PHP-Markdown-Extended Developer Manual"
.SH NAME
.PP
PHP-Markdown-Extended API - Developer documentation of the internal API of the "piwi/markdown-extended" package.
.PP
The whole API is stored in the `\fS\\MarkdownExtended\\API\fP` namespace and is a set of interfaces
you must implement to use or override the parser or some of its objects.
.SH PARSER OPTIONS
.PP
The parser can accept a large set of options to customize or adapt the final
rendering. For a complete list, please see the `\fSgetDefaults()\fP` method
of the `\fS\\MarkdownExtended\\MarkdownExtended\fP` class <http://docs.ateliers-pierrot.fr/markdown-extended/MarkdownExtended/MarkdownExtended.html>.
.PP
Below is a review of interesting basic options:
.TP
config_file
Type: file path
Default: `\fSnull\fP`
Define a configuration file to overwrite defaults ; configuration files may be
in INI <http://en.wikipedia.org/wiki/INI_file>, JSON <http://json.org/> or 
raw PHP array <http://php.net/array> formats (it must return an array).
.TP
template
Type: bool / 'auto' / file path
Default: `\fSfalse\fP` if the content has no metadata / `\fStrue\fP` otherwise
If it is `\fStrue\fP`, the default (basic) template is used, otherwise, the template
defined at `\fSfile path\fP` will be used. The default value is `\fSauto\fP`, which lets the
parser choose if a template seems required (basically if the parsed content has
metadata or not). You can set it on `\fSfalse\fP` to never use a template.
.TP
template_options
Type: array
Default: \fIsee sources\fP
The template object options.
.TP
output_format
Type: string
Default: `\fShtml\fP`
The output format to use to build final rendering.
.TP
output_format_options
Type: array
Default: \fIsee sources\fP
The output formats options, stored by output formats type (`\fSoutput_format_options.html = array( ... )\fP`).
.TP
output
Type: string
Default: `\fSnull\fP`
When it is defined, this option will be used to build a file name to write parsing result in ;
it can be defined as a mask like `\fSoutput-filename-%%.html\fP` where `\fS%%\fP` will be filled with current
content file path or title ; when parsing multiple inputs,
.PP
Some options can be defined as \fIcallbacks\fP to process a custom logic when necessary:
.RS

.EX
my_option = function(arg) { ...; return $arg; }
.EE
.RE
.SH PARSER FILTERS
.PP
Each filters' list executed while parsing a full content or a peace of a content
is defined as a `\fSxxx_gamuts\fP` array configuration entry with filter's name as
item's key and its order as item's value. Each gamut sub-item is constructed like
.RS

.EX
gamut_alias or class name : method or class name : method name
.EE
.RE
.PP
i.e.
.RS

.EX
// call the default method of filter Detab
.br
\'filter:Detab'              => '5',
.br

.br
// call the init() method of filter Detab
.br
\'filter:Detab:init'         => '10',
.br

.br
// call the RemoveUtf8Marker tool
.br
\'tool:RemoveUtf8Marker'     => '15',
.br

.br
// call another gamuts stack
.br
\'block_gamut'               => '30',
.EE
.RE
.PP
Below is a list of gamuts stacks used by the parser:
.RS
.IP \(bu 
`\fSinitial_gamut\fP`
.IP \(bu 
`\fStransform_gamut\fP`
.IP \(bu 
`\fSdocument_gamut\fP`
.IP \(bu 
`\fSspan_gamut\fP`
.IP \(bu 
`\fSblock_gamut\fP`
.IP \(bu 
`\fShtml_block_gamut\fP`
.RE
.PP
You can define and use a custom filter by defining a PHP object that is compliant with
the API (see below) and inserting it in a gamuts stack.
.SH LIFE-CYCLE
.PP
The full schema of a Markdown parser usage could be:
.RS

.EX
[source file content]   [options]                                  [template]
.br
       ||                  ||                                         /\\
.br
       \\/                  \\/                                         ||
.br
---------------        ----------                            --------------------
.br
|  MD SOURCE  |   =>   | PARSER |   =>  [output format]  =>  | FORMATTED RESULT |
.br
---------------        ----------                            --------------------
.br
       /\\                  /\\                                         ||
.br
       ||                  ||                                         \\/
.br
    [string]         [configuration]                            [special info]
.EE
.RE
.PP
The original Markdown source can be either a buffered string (a form field for example)
or the content of a Markdown file.
.PP
We want to parse the source content with a hand on options used during this parsing
(no need to parse metadata in a content that will never have some for example).
.PP
Finally, we want to get a formatted content and to be able to retrieve certain information
from it, such as its metadata, its footnotes or the whole parsed result.
.PP
Additionally, it would be best that we can obtain a full formatted result simply but
can also pass this result through a template builder to construct a complex final string.
.SH PARSER API
.PP
The public direct parser's access is the `\fS\\MarkdownExtended\\MarkdownExtended\fP`
object. It handles transformation and constructs dependencies. It returns a
parsed content as a `\fS\\MarkdownExtended\\Content\fP` object implementing the API
interface `\fS\\MarkdownExtended\\API\\ContentInterface\fP`. The rendered final format
transformations are done by an object implementing the API interface
`\fS\\MarkdownExtended\\API\\OutputFormatInterface\fP` which is called and managed
by the `\fS\\MarkdownExtended\\OutputFormatBag\fP` object. Internal available formats
are stored in the `\fS\\MarkdownExtended\\OutputFormat\fP` namespace. The filters applied
during content's parsing are managed by the `\fS\\MarkdownExtended\\Grammar\\Lexer\fP`
object, which actually call various "gamuts" methods or classes using the
`\fS\\MarkdownExtended\\Grammar\\GamutsLoader\fP` object. Each filter gamut is an
object implementing the API interface `\fS\\MarkdownExtended\\API\\GamutInterface\fP`.
The parser can load parsed content in a template file using an object implementing
the API interface `\fS\\MarkdownExtended\\API\\TemplateInterface\fP` and defaults to
the `\fS\\MarkdownExtended\\Templater\fP` object.
.PP
Finally, the internal central service container registering all the objects
involved in the parsing process is the `\fS\\MarkdownExtended\\API\\Kernel\fP`, which
only contains static methods.
.SS Public \fIMarkdownExtended\fP
.PP
The public `\fS\\MarkdownExtended\\MarkdownExtended\fP` object follows a simple static API:
.RS

.EX
\\MarkdownExtended\\MarkdownExtended::parse( content/file path , options ) : \\MarkdownExtended\\Content
.br

.br
\\MarkdownExtended\\MarkdownExtended::parseString( content , options ) : \\MarkdownExtended\\Content
.br

.br
\\MarkdownExtended\\MarkdownExtended::parseFile( file path , options ) : \\MarkdownExtended\\Content
.EE
.RE
.PP
These methods actually distribute the "real" work to the `\fS\\MarkdownExtended\\Parser\fP` 
object, which can be used as a literal procedural object like:
.RS

.EX
$parser = new \\MarkdownExtended\\Parser( options );
.br

.br
$content = $parser->transform( source string );
.br

.br
$content = $parser->transformSource( source file path );
.EE
.RE
.PP
You can use both `\fS\\MarkdownExtended\\Parser\fP` and `\fS\\MarkdownExtended\\MarkdownExtended\fP`
objects in this case.
.SS The \fIContent\fP object
.PP
The transformation process of the parser returns an object implementing interface
`\fS\\MarkdownExtended\\API\\ContentInterface\fP`. You can define your own object by passing
it directly to the `\fS\\MarkdownExtended\\MarkdownExtended\fP` parse methods (instead of a
raw string or file name).
.PP
The content object API allows to access each "block" of content and
to write the object directly:
.RS

.EX
string  Content::__toString()
.br
array   Content::__toArray()
.br

.br
string  Content::getContent()
.br

.br
string  Content::getCharset()
.br
string  Content::getTitle()
.br
string  Content::getBody()
.br
array   Content::getNotes()
.br
array   Content::getMetadata()
.br

.br
string  Content::getNotesFormatted()
.br
string  Content::getMetadataFormatted()
.br

.br
string  Content::getSource()
.br
array   Content::getParsingOptions()
.EE
.RE
.PP
The special `\fSget...Formatted()\fP` methods are designed to render a string from an array
of information (basically footnotes and metadata). Metadata follows a special logic
as the data with a name in the `\fSspecial_metadata\fP` option will be stripped from the
output (you can customize this option to use a metadata but not actually render it).
.SS The \fIFilters\fP objects
.PP
A filter must implement the `\fS\\MarkdownExtended\\API\\GamutInterface\fP` interface 
and may extend the `\fS\\MarkdownExtended\\Grammar\\Filter\fP` object:
.RS

.EX
Filter->getDefaultMethod()
.br
Filter->transform( text )
.EE
.RE
.PP
Filters stacks to run during transformation are defined in the `\fSxxx_gamut\fP` items
of the configuration.
.SS The \fIOutputFormat\fP rendering
.PP
An output format renderer must implement the `\fS\\MarkdownExtended\\API\\OutputFormatInterface\fP`
interface, which defines some basic methods to build a content:
.RS

.EX
OutputFormat->buildTag( tag_name, content = null, array attributes = array() )
.br

.br
OutputFormat->getTagString( content, tag_name, array attributes = array() )
.EE
.RE
.PP
The interface also defines two methods called to process the `\fSget...Formatted()\fP` logic
of the content:
.RS

.EX
OutputFormat->getNotesToString( array notes , content )
.br

.br
OutputFormat->getMetadataToString( array metadata , content )
.EE
.RE
.SS The \fITemplate\fP renderer
.PP
A template object must implement the `\fS\\MarkdownExtended\\API\\TemplateInterface\fP`
interface, which contains one single method:
.RS

.EX
Template->parse( ContentInterface )
.EE
.RE
.SS The app's \fIKernel\fP
.PP
It acts like a service container:
.RS

.EX
\\MarkdownExtended\\Kernel::get('MarkdownExtended')   // the parser singleton
.br
\\MarkdownExtended\\Kernel::get('Content')            // current parsed content
.br
\\MarkdownExtended\\Kernel::get('ContentCollection')  // parsed contents collection
.br
\\MarkdownExtended\\Kernel::get('Lexer')              // grammar lexer
.br
\\MarkdownExtended\\Kernel::get('GamutLoader')        // grammar gamuts loader
.br
\\MarkdownExtended\\Kernel::get('OutputFormatBag')    // wrapper for current output format
.br
\\MarkdownExtended\\Kernel::get('Template')           // template engine
.br
\\MarkdownExtended\\Kernel::get('DomId')              // DOM registry manager
.EE
.RE
.PP
It also acts like a configuration setter/getter:
.RS

.EX
// set a configuration entry
.br
\\MarkdownExtended\\Kernel::setConfig( index.subindex , value )
.br

.br
// merge a configuration entry with any existing string or array value
.br
\\MarkdownExtended\\Kernel::addConfig( index.subindex , value )
.br

.br
// get a configuration entry
.br
\\MarkdownExtended\\Kernel::getConfig( index.subindex )
.br

.br
// apply a callback configuration entry on a list of parameters
.br
\\MarkdownExtended\\Kernel::applyConfig( index.subindex , parameters )
.EE
.RE
.SS Exceptions & errors
.PP
A full set of specific exceptions is defined in the app to differentiate external
and internal errors. Internal errors only defines a specific error code you can retrieve
with `\fS$exception->getCode()\fP` between 90 and 95:
.RS
.IP \(bu 
\fI90\fP is the default exception thrown when invalid arguments are met
(basic usage error - `\fS\\MarkdownExtended\\Exception\\InvalidArgumentException\fP`)
.IP \(bu 
\fI91\fP is the default exception thrown when a file or directory could not be found, read or written
(`\fS\\MarkdownExtended\\Exception\\FileSystemException\fP`)
.IP \(bu 
\fI92\fP is the default exception thrown when an invalid value is met
(deeper usage error - `\fS\\MarkdownExtended\\Exception\\UnexpectedValueException\fP`)
.IP \(bu 
\fI93\fP is the default exception thrown when an error occurred at runtime
(`\fS\\MarkdownExtended\\Exception\\RuntimeException\fP`)
.IP \(bu 
\fI94\fP is the default exception status
(`\fS\\MarkdownExtended\\Exception\\Exception\fP`)
.IP \(bu 
\fI95\fP is the default error-exception status
(development error - `\fS\\MarkdownExtended\\Exception\\ErrorException\fP`)
.RE
.SH SEE ALSO
.PP
An online documentation of last stable version is available at
<http://docs.ateliers-pierrot.fr/markdown-extended/>.
.PP
php(1), pcre(3), markdown-extended(3)
